leaftools.leaf_to_augmented_tuplet_with_proportions
===================================================

.. autofunction:: abjad.tools.leaftools.leaf_to_augmented_tuplet_with_proportions.leaf_to_augmented_tuplet_with_proportions
